@@ -18,6 +18,9 @@ from dagster.core.events import DagsterEventType
 from dagster.core.events.log import EventLogEntry
 from dagster.core.execution.plan.objects import StepFailureData
 
+MAX_INT = 2147483647
+MIN_INT = -2147483648
+
 
 def iterate_metadata_entries(metadata_entries):
     from ..schema.logs.events import (
@@ -87,7 +90,7 @@ def iterate_metadata_entries(metadata_entries):
         elif isinstance(metadata_entry.entry_data, IntMetadataEntryData):
             # coerce > 32 bit ints to null
             int_val = None
-            if metadata_entry.entry_data.value.bit_length() <= 32:
+            if MIN_INT <= metadata_entry.entry_data.value <= MAX_INT:
                 int_val = metadata_entry.entry_data.value
 
             yield GrapheneEventIntMetadataEntry(
@@ -139,14 +142,14 @@ def from_dagster_event_record(event_record, pipeline_name):
         GrapheneLoadedInputEvent,
         GrapheneLogsCapturedEvent,
         GrapheneObjectStoreOperationEvent,
-        GraphenePipelineCanceledEvent,
-        GraphenePipelineCancelingEvent,
-        GraphenePipelineDequeuedEvent,
-        GraphenePipelineEnqueuedEvent,
-        GraphenePipelineFailureEvent,
-        GraphenePipelineStartEvent,
-        GraphenePipelineStartingEvent,
-        GraphenePipelineSuccessEvent,
+        GrapheneRunCanceledEvent,
+        GrapheneRunCancelingEvent,
+        GrapheneRunDequeuedEvent,
+        GrapheneRunEnqueuedEvent,
+        GrapheneRunFailureEvent,
+        GrapheneRunStartEvent,
+        GrapheneRunStartingEvent,
+        GrapheneRunSuccessEvent,
         GrapheneStepExpectationResultEvent,
         GrapheneStepMaterializationEvent,
         GrapheneAlertStartEvent,
@@ -204,33 +207,60 @@ def from_dagster_event_record(event_record, pipeline_name):
     elif dagster_event.event_type == DagsterEventType.STEP_FAILURE:
         check.inst(dagster_event.step_failure_data, StepFailureData)
         return GrapheneExecutionStepFailureEvent(
-            error=GraphenePythonError(dagster_event.step_failure_data.error),
+            error=(
+                GraphenePythonError(dagster_event.step_failure_data.error)
+                if dagster_event.step_failure_data.error
+                else None
+            ),
             failureMetadata=dagster_event.step_failure_data.user_failure_data,
             errorSource=dagster_event.step_failure_data.error_source,
             **basic_params,
         )
-    elif dagster_event.event_type == DagsterEventType.PIPELINE_ENQUEUED:
-        return GraphenePipelineEnqueuedEvent(pipelineName=pipeline_name, **basic_params)
-    elif dagster_event.event_type == DagsterEventType.PIPELINE_DEQUEUED:
-        return GraphenePipelineDequeuedEvent(pipelineName=pipeline_name, **basic_params)
-    elif dagster_event.event_type == DagsterEventType.PIPELINE_STARTING:
-        return GraphenePipelineStartingEvent(pipelineName=pipeline_name, **basic_params)
-    elif dagster_event.event_type == DagsterEventType.PIPELINE_CANCELING:
-        return GraphenePipelineCancelingEvent(pipelineName=pipeline_name, **basic_params)
-    elif dagster_event.event_type == DagsterEventType.PIPELINE_CANCELED:
-        return GraphenePipelineCanceledEvent(pipelineName=pipeline_name, **basic_params)
-    elif dagster_event.event_type == DagsterEventType.PIPELINE_START:
-        return GraphenePipelineStartEvent(pipelineName=pipeline_name, **basic_params)
-    elif dagster_event.event_type == DagsterEventType.PIPELINE_SUCCESS:
-        return GraphenePipelineSuccessEvent(pipelineName=pipeline_name, **basic_params)
-    elif dagster_event.event_type == DagsterEventType.PIPELINE_FAILURE:
-        return GraphenePipelineFailureEvent(
+
+    elif dagster_event.event_type in (
+        DagsterEventType.RUN_ENQUEUED,
+        DagsterEventType.PIPELINE_ENQUEUED,
+    ):
+        return GrapheneRunEnqueuedEvent(pipelineName=pipeline_name, **basic_params)
+    elif dagster_event.event_type in (
+        DagsterEventType.RUN_DEQUEUED,
+        DagsterEventType.PIPELINE_DEQUEUED,
+    ):
+        return GrapheneRunDequeuedEvent(pipelineName=pipeline_name, **basic_params)
+    elif dagster_event.event_type in (
+        DagsterEventType.RUN_STARTING,
+        DagsterEventType.PIPELINE_STARTING,
+    ):
+        return GrapheneRunStartingEvent(pipelineName=pipeline_name, **basic_params)
+    elif dagster_event.event_type in (
+        DagsterEventType.RUN_CANCELING,
+        DagsterEventType.PIPELINE_CANCELING,
+    ):
+        return GrapheneRunCancelingEvent(pipelineName=pipeline_name, **basic_params)
+    elif dagster_event.event_type in (
+        DagsterEventType.RUN_CANCELED,
+        DagsterEventType.PIPELINE_CANCELED,
+    ):
+        return GrapheneRunCanceledEvent(pipelineName=pipeline_name, **basic_params)
+    elif dagster_event.event_type in (DagsterEventType.RUN_START, DagsterEventType.PIPELINE_START):
+        return GrapheneRunStartEvent(pipelineName=pipeline_name, **basic_params)
+    elif dagster_event.event_type in (
+        DagsterEventType.RUN_SUCCESS,
+        DagsterEventType.PIPELINE_SUCCESS,
+    ):
+        return GrapheneRunSuccessEvent(pipelineName=pipeline_name, **basic_params)
+    elif dagster_event.event_type in (
+        DagsterEventType.RUN_FAILURE,
+        DagsterEventType.PIPELINE_FAILURE,
+    ):
+        return GrapheneRunFailureEvent(
             pipelineName=pipeline_name,
             error=GraphenePythonError(dagster_event.pipeline_failure_data.error)
             if (dagster_event.pipeline_failure_data and dagster_event.pipeline_failure_data.error)
             else None,
             **basic_params,
         )
+
     elif dagster_event.event_type == DagsterEventType.ALERT_START:
         return GrapheneAlertStartEvent(pipelineName=pipeline_name, **basic_params)
     elif dagster_event.event_type == DagsterEventType.ALERT_SUCCESS:
