@@ -2,7 +2,7 @@ import sys
 from collections import namedtuple
 
 from dagster import check
-from dagster.core.host_representation import PipelineSelector
+from dagster.core.host_representation import GraphSelector, PipelineSelector
 from dagster.utils.error import serializable_error_info_from_exc_info
 from graphql.execution.base import ResolveInfo
 
@@ -59,6 +59,14 @@ def pipeline_selector_from_graphql(data):
     )
 
 
+def graph_selector_from_graphql(data):
+    return GraphSelector(
+        location_name=data["repositoryLocationName"],
+        repository_name=data["repositoryName"],
+        graph_name=data["graphName"],
+    )
+
+
 class ExecutionParams(
     namedtuple(
         "_ExecutionParams",
@@ -73,7 +81,7 @@ class ExecutionParams(
             cls,
             selector=check.inst_param(selector, "selector", PipelineSelector),
             run_config=run_config,
-            mode=check.str_param(mode, "mode"),
+            mode=check.opt_str_param(mode, "mode"),
             execution_metadata=check.inst_param(
                 execution_metadata, "execution_metadata", ExecutionMetadata
             ),
