@@ -1,13 +1,10 @@
-from functools import lru_cache
-
 import graphene
 import yaml
 from dagster import check
-from dagster.core.events import StepMaterializationData
+from dagster.core.events import AssetKey, StepMaterializationData
 from dagster.core.events.log import EventLogEntry
 from dagster.core.host_representation.external import ExternalExecutionPlan, ExternalPipeline
 from dagster.core.host_representation.external_data import ExternalPresetData
-from dagster.core.host_representation.represented import RepresentedPipeline
 from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus, PipelineRunsFilter
 from dagster.core.storage.tags import TagType, get_tag_type
 
@@ -22,6 +19,7 @@ from ..asset_key import GrapheneAssetKey
 from ..dagster_types import GrapheneDagsterType, GrapheneDagsterTypeOrError, to_dagster_type
 from ..errors import GrapheneDagsterTypeNotFoundError, GraphenePythonError, GrapheneRunNotFoundError
 from ..execution import GrapheneExecutionPlan
+from ..inputs import GrapheneAssetKeyInput
 from ..logs.compute_logs import GrapheneComputeLogs
 from ..logs.events import (
     GrapheneDagsterRunEvent,
@@ -30,6 +28,7 @@ from ..logs.events import (
 )
 from ..paging import GrapheneCursor
 from ..repository_origin import GrapheneRepositoryOrigin
+from ..runs import GrapheneRunConfigData
 from ..schedules.schedules import GrapheneSchedule
 from ..sensors import GrapheneSensor
 from ..solids import (
@@ -39,7 +38,7 @@ from ..solids import (
     build_solid_handles,
     build_solids,
 )
-from ..tags import GrapheneAssetTag, GraphenePipelineTag
+from ..tags import GraphenePipelineTag
 from ..util import non_null_list
 from .mode import GrapheneMode
 from .pipeline_ref import GraphenePipelineReference
@@ -85,17 +84,11 @@ class GrapheneAsset(graphene.ObjectType):
         beforeTimestampMillis=graphene.String(),
         limit=graphene.Int(),
     )
-    tags = non_null_list(GrapheneAssetTag)
     definition = graphene.Field("dagster_graphql.schema.asset_graph.GrapheneAssetNode")
 
     class Meta:
         name = "Asset"
 
-    def __init__(self, key, definition=None, tags=None):
-        super().__init__(key=key, definition=definition)
-        check.opt_dict_param(tags, "tags", key_type=str, value_type=str)
-        self._tags = tags
-
     def resolve_id(self, _):
         return self.key
 
@@ -111,24 +104,20 @@ class GrapheneAsset(graphene.ObjectType):
         except ValueError:
             before_timestamp = None
 
+        limit = kwargs.get("limit")
+        partitions = kwargs.get("partitions")
+
         return [
             GrapheneAssetMaterialization(event=event)
             for event in get_asset_events(
                 graphene_info,
                 self.key,
-                kwargs.get("partitions"),
+                partitions=partitions,
                 before_timestamp=before_timestamp,
-                limit=kwargs.get("limit"),
+                limit=limit,
             )
         ]
 
-    def resolve_tags(self, graphene_info):
-        if self._tags is not None:
-            tags = self._tags
-        else:
-            tags = graphene_info.context.instance.get_asset_tags(self.key)
-        return [GrapheneAssetTag(key=key, value=value) for key, value in tags.items()]
-
 
 class GraphenePipelineRun(graphene.Interface):
     id = graphene.NonNull(graphene.ID)
@@ -153,6 +142,7 @@ class GraphenePipelineRun(graphene.Interface):
     executionPlan = graphene.Field(GrapheneExecutionPlan)
     stepKeysToExecute = graphene.List(graphene.NonNull(graphene.String))
     runConfigYaml = graphene.NonNull(graphene.String)
+    runConfig = graphene.NonNull(GrapheneRunConfigData)
     mode = graphene.NonNull(graphene.String)
     tags = non_null_list(GraphenePipelineTag)
     rootRunId = graphene.Field(graphene.String)
@@ -179,6 +169,7 @@ class GrapheneRun(graphene.ObjectType):
     pipelineName = graphene.NonNull(graphene.String)
     jobName = graphene.NonNull(graphene.String)
     solidSelection = graphene.List(graphene.NonNull(graphene.String))
+    resolvedOpSelection = graphene.List(graphene.NonNull(graphene.String))
     stats = graphene.NonNull(GrapheneRunStatsSnapshotOrError)
     stepStats = non_null_list(GrapheneRunStepStats)
     computeLogs = graphene.Field(
@@ -191,6 +182,7 @@ class GrapheneRun(graphene.ObjectType):
     executionPlan = graphene.Field(GrapheneExecutionPlan)
     stepKeysToExecute = graphene.List(graphene.NonNull(graphene.String))
     runConfigYaml = graphene.NonNull(graphene.String)
+    runConfig = graphene.NonNull(GrapheneRunConfigData)
     mode = graphene.NonNull(graphene.String)
     tags = non_null_list(GraphenePipelineTag)
     rootRunId = graphene.Field(graphene.String)
@@ -238,6 +230,9 @@ class GrapheneRun(graphene.ObjectType):
     def resolve_solidSelection(self, _graphene_info):
         return self._pipeline_run.solid_selection
 
+    def resolve_resolvedOpSelection(self, _graphene_info):
+        return self._pipeline_run.solids_to_execute
+
     def resolve_pipelineSnapshotId(self, _graphene_info):
         return self._pipeline_run.pipeline_snapshot_id
 
@@ -258,20 +253,15 @@ class GrapheneRun(graphene.ObjectType):
             return None
 
         instance = graphene_info.context.instance
-        historical_pipeline = instance.get_historical_pipeline(
-            self._pipeline_run.pipeline_snapshot_id
-        )
+
         execution_plan_snapshot = instance.get_execution_plan_snapshot(
             self._pipeline_run.execution_plan_snapshot_id
         )
         return (
             GrapheneExecutionPlan(
-                ExternalExecutionPlan(
-                    execution_plan_snapshot=execution_plan_snapshot,
-                    represented_pipeline=historical_pipeline,
-                )
+                ExternalExecutionPlan(execution_plan_snapshot=execution_plan_snapshot)
             )
-            if execution_plan_snapshot and historical_pipeline
+            if execution_plan_snapshot
             else None
         )
 
@@ -283,6 +273,9 @@ class GrapheneRun(graphene.ObjectType):
             self._pipeline_run.run_config, default_flow_style=False, allow_unicode=True
         )
 
+    def resolve_runConfig(self, _graphene_info):
+        return self._pipeline_run.run_config
+
     def resolve_tags(self, _graphene_info):
         return [
             GraphenePipelineTag(key=key, value=value)
@@ -418,10 +411,10 @@ class GrapheneIPipelineSnapshotMixin:
         ]
 
     def resolve_solid_handle(self, _graphene_info, handleID):
-        return _get_solid_handles(self.get_represented_pipeline()).get(handleID)
+        return build_solid_handles(self.get_represented_pipeline()).get(handleID)
 
     def resolve_solid_handles(self, _graphene_info, **kwargs):
-        handles = _get_solid_handles(self.get_represented_pipeline())
+        handles = build_solid_handles(self.get_represented_pipeline())
         parentHandleID = kwargs.get("parentHandleID")
 
         if parentHandleID == "":
@@ -559,6 +552,13 @@ class GraphenePipeline(GrapheneIPipelineSnapshotMixin, graphene.ObjectType):
     id = graphene.NonNull(graphene.ID)
     presets = non_null_list(GraphenePipelinePreset)
     isJob = graphene.NonNull(graphene.Boolean)
+    isAssetJob = graphene.NonNull(graphene.Boolean)
+    repository = graphene.NonNull("dagster_graphql.schema.external.GrapheneRepository")
+    assetNodes = graphene.Field(
+        non_null_list("dagster_graphql.schema.asset_graph.GrapheneAssetNode"),
+        assetKeys=graphene.Argument(graphene.List(graphene.NonNull(GrapheneAssetKeyInput))),
+        loadMaterializations=graphene.Boolean(default_value=False),
+    )
 
     class Meta:
         interfaces = (GrapheneSolidContainer, GrapheneIPipelineSnapshot)
@@ -585,6 +585,54 @@ class GraphenePipeline(GrapheneIPipelineSnapshotMixin, graphene.ObjectType):
     def resolve_isJob(self, _graphene_info):
         return self._external_pipeline.is_job
 
+    def resolve_isAssetJob(self, graphene_info):
+        handle = self._external_pipeline.repository_handle
+        location = graphene_info.context.get_repository_location(handle.location_name)
+        repository = location.get_repository(handle.repository_name)
+        return bool(repository.get_external_asset_nodes(self._external_pipeline.name))
+
+    def resolve_repository(self, graphene_info):
+        from ..external import GrapheneRepository
+
+        handle = self._external_pipeline.repository_handle
+        location = graphene_info.context.get_repository_location(handle.location_name)
+        return GrapheneRepository(location.get_repository(handle.repository_name), location)
+
+    def resolve_assetNodes(self, graphene_info, **kwargs):
+        from ..asset_graph import GrapheneAssetNode
+
+        load_materializations = kwargs.get("loadMaterializations")
+
+        handle = self._external_pipeline.repository_handle
+        location = graphene_info.context.get_repository_location(handle.location_name)
+        repository = location.get_repository(handle.repository_name)
+        asset_nodes = repository.get_external_asset_nodes(self._external_pipeline.name)
+        if not asset_nodes:
+            return []
+        asset_keys = set(
+            AssetKey.from_graphql_input(asset_key) for asset_key in kwargs.get("assetKeys", [])
+        )
+        matching = [node for node in asset_nodes if not asset_keys or node.asset_key in asset_keys]
+        if not matching:
+            return []
+
+        if load_materializations:
+            events_by_key = graphene_info.context.instance.get_latest_materialization_events(
+                [node.asset_key for node in matching]
+            )
+        else:
+            events_by_key = {}
+
+        return [
+            GrapheneAssetNode(
+                repository,
+                node,
+                events_by_key.get(node.asset_key),
+                fetched_materialization=load_materializations,
+            )
+            for node in matching
+        ]
+
 
 class GrapheneJob(GraphenePipeline):
     class Meta:
@@ -592,18 +640,77 @@ class GrapheneJob(GraphenePipeline):
         name = "Job"
 
 
-@lru_cache(maxsize=32)
-def _get_solid_handles(represented_pipeline):
-    check.inst_param(represented_pipeline, "represented_pipeline", RepresentedPipeline)
-    return {
-        str(item.handleID): item
-        for item in build_solid_handles(
-            represented_pipeline, represented_pipeline.dep_structure_index
+class GrapheneGraph(graphene.ObjectType):
+    class Meta:
+        interfaces = (GrapheneSolidContainer,)
+        name = "Graph"
+
+    id = graphene.NonNull(graphene.ID)
+    name = graphene.NonNull(graphene.String)
+    description = graphene.String()
+    solid_handle = graphene.Field(
+        GrapheneSolidHandle,
+        handleID=graphene.Argument(graphene.NonNull(graphene.String)),
+    )
+    solid_handles = graphene.Field(
+        non_null_list(GrapheneSolidHandle), parentHandleID=graphene.String()
+    )
+    modes = non_null_list(GrapheneMode)
+
+    def __init__(self, external_pipeline, solid_handle_id=None):
+        self._external_pipeline = check.inst_param(
+            external_pipeline, "external_pipeline", ExternalPipeline
         )
-    }
+        self._solid_handle_id = check.opt_str_param(solid_handle_id, "solid_handle_id")
+        super().__init__()
+
+    def resolve_id(self, _graphene_info):
+        if self._solid_handle_id:
+            return (
+                f"{self._external_pipeline.get_external_origin_id()}:solid:{self._solid_handle_id}"
+            )
+        return f"graph:{self._external_pipeline.get_external_origin_id()}"
+
+    def resolve_name(self, _graphene_info):
+        return self._external_pipeline.get_graph_name()
+
+    def resolve_description(self, _graphene_info):
+        return self._external_pipeline.description
+
+    def resolve_solid_handle(self, _graphene_info, handleID):
+        return build_solid_handles(self._external_pipeline).get(handleID)
+
+    def resolve_solid_handles(self, _graphene_info, **kwargs):
+        handles = build_solid_handles(self._external_pipeline)
+        parentHandleID = kwargs.get("parentHandleID")
+
+        if parentHandleID == "":
+            handles = {key: handle for key, handle in handles.items() if not handle.parent}
+        elif parentHandleID is not None:
+            handles = {
+                key: handle
+                for key, handle in handles.items()
+                if handle.parent and handle.parent.handleID.to_string() == parentHandleID
+            }
+
+        return [handles[key] for key in sorted(handles)]
+
+    def resolve_modes(self, _graphene_info):
+        # returns empty list... graphs don't have modes, this is a vestige of the old
+        # pipeline explorer, which expected all solid containers to be pipelines
+        return []
 
 
 class GrapheneRunOrError(graphene.Union):
     class Meta:
         types = (GrapheneRun, GrapheneRunNotFoundError, GraphenePythonError)
         name = "RunOrError"
+
+
+class GrapheneInProgressRunsByStep(graphene.ObjectType):
+    stepKey = graphene.NonNull(graphene.String)
+    unstartedRuns = non_null_list(GrapheneRun)
+    inProgressRuns = non_null_list(GrapheneRun)
+
+    class Meta:
+        name = "InProgressRunsByStep"
