@@ -13,6 +13,7 @@ from ...implementation.execution import (
     wipe_assets,
 )
 from ...implementation.external import fetch_workspace, get_full_external_pipeline_or_raise
+from ...implementation.telemetry import log_dagit_telemetry_event
 from ...implementation.utils import (
     ExecutionMetadata,
     ExecutionParams,
@@ -41,11 +42,7 @@ from ..external import GrapheneWorkspace, GrapheneWorkspaceLocationEntry
 from ..inputs import GrapheneAssetKeyInput, GrapheneExecutionParams, GrapheneLaunchBackfillParams
 from ..pipelines.pipeline import GrapheneRun
 from ..runs import GrapheneLaunchRunReexecutionResult, GrapheneLaunchRunResult
-from ..schedules import (
-    GrapheneReconcileSchedulerStateMutation,
-    GrapheneStartScheduleMutation,
-    GrapheneStopRunningScheduleMutation,
-)
+from ..schedules import GrapheneStartScheduleMutation, GrapheneStopRunningScheduleMutation
 from ..sensors import GrapheneStartSensorMutation, GrapheneStopSensorMutation
 from ..util import non_null_list
 
@@ -477,12 +474,52 @@ class GrapheneAssetWipeMutation(graphene.Mutation):
         )
 
 
-class GrapheneMutation(graphene.ObjectType):
+class GrapheneLogTelemetrySuccess(graphene.ObjectType):
+    action = graphene.NonNull(graphene.String)
+
+    class Meta:
+        name = "LogTelemetrySuccess"
+
+
+class GrapheneLogTelemetryMutationResult(graphene.Union):
+    class Meta:
+        types = (
+            GrapheneLogTelemetrySuccess,
+            GraphenePythonError,
+        )
+        name = "LogTelemetryMutationResult"
+
+
+class GrapheneLogTelemetryMutation(graphene.Mutation):
+    Output = graphene.NonNull(GrapheneLogTelemetryMutationResult)
+
+    class Arguments:
+        action = graphene.Argument(graphene.NonNull(graphene.String))
+        clientTime = graphene.Argument(graphene.NonNull(graphene.String))
+        metadata = graphene.Argument(graphene.NonNull(graphene.String))
+
+    class Meta:
+        name = "LogTelemetryMutation"
+
+    @capture_error
+    def mutate(self, graphene_info, **kwargs):
+        action = log_dagit_telemetry_event(
+            graphene_info,
+            action=kwargs["action"],
+            client_time=kwargs["clientTime"],
+            metadata=kwargs["metadata"],
+        )
+        return action
+
+
+class GrapheneDagitMutation(graphene.ObjectType):
+    class Meta:
+        name = "DagitMutation"
+
     launch_pipeline_execution = GrapheneLaunchRunMutation.Field()
     launch_run = GrapheneLaunchRunMutation.Field()
     launch_pipeline_reexecution = GrapheneLaunchRunReexecutionMutation.Field()
     launch_run_reexecution = GrapheneLaunchRunReexecutionMutation.Field()
-    reconcile_scheduler_state = GrapheneReconcileSchedulerStateMutation.Field()
     start_schedule = GrapheneStartScheduleMutation.Field()
     stop_running_schedule = GrapheneStopRunningScheduleMutation.Field()
     start_sensor = GrapheneStartSensorMutation.Field()
@@ -498,6 +535,4 @@ class GrapheneMutation(graphene.ObjectType):
     launch_partition_backfill = GrapheneLaunchBackfillMutation.Field()
     resume_partition_backfill = GrapheneResumeBackfillMutation.Field()
     cancel_partition_backfill = GrapheneCancelBackfillMutation.Field()
-
-    class Meta:
-        name = "Mutation"
+    log_telemetry = GrapheneLogTelemetryMutation.Field()
