@@ -7,7 +7,7 @@ from dagster.core.host_representation import (
     ScheduleSelector,
     SensorSelector,
 )
-from dagster.core.scheduler.job import JobType
+from dagster.core.scheduler.instigation import InstigatorType
 
 from ...implementation.external import fetch_repositories, fetch_repository, fetch_workspace
 from ...implementation.fetch_assets import get_asset, get_asset_node, get_asset_nodes, get_assets
@@ -33,8 +33,9 @@ from ...implementation.fetch_schedules import (
     get_schedules_or_error,
 )
 from ...implementation.fetch_sensors import get_sensor_or_error, get_sensors_or_error
+from ...implementation.fetch_solids import get_graph_or_error
 from ...implementation.run_config_schema import resolve_run_config_schema_or_error
-from ...implementation.utils import pipeline_selector_from_graphql
+from ...implementation.utils import graph_selector_from_graphql, pipeline_selector_from_graphql
 from ..asset_graph import GrapheneAssetNode, GrapheneAssetNodeOrError
 from ..backfill import GraphenePartitionBackfillOrError, GraphenePartitionBackfillsOrError
 from ..external import (
@@ -44,6 +45,7 @@ from ..external import (
 )
 from ..inputs import (
     GrapheneAssetKeyInput,
+    GrapheneGraphSelector,
     GrapheneInstigationSelector,
     GraphenePipelineSelector,
     GrapheneRepositorySelector,
@@ -76,10 +78,13 @@ from ..tags import GraphenePipelineTagAndValues
 from ..util import non_null_list
 from .assets import GrapheneAssetOrError, GrapheneAssetsOrError
 from .execution_plan import GrapheneExecutionPlanOrError
-from .pipeline import GraphenePipelineOrError
+from .pipeline import GrapheneGraphOrError, GraphenePipelineOrError
 
 
-class GrapheneQuery(graphene.ObjectType):
+class GrapheneDagitQuery(graphene.ObjectType):
+    class Meta:
+        name = "DagitQuery"
+
     version = graphene.NonNull(graphene.String)
 
     repositoriesOrError = graphene.NonNull(GrapheneRepositoriesOrError)
@@ -100,6 +105,11 @@ class GrapheneQuery(graphene.ObjectType):
         activePipelineSelector=graphene.Argument(GraphenePipelineSelector),
     )
 
+    graphOrError = graphene.Field(
+        graphene.NonNull(GrapheneGraphOrError),
+        selector=graphene.Argument(GrapheneGraphSelector),
+    )
+
     scheduler = graphene.Field(graphene.NonNull(GrapheneSchedulerOrError))
 
     scheduleOrError = graphene.Field(
@@ -235,9 +245,6 @@ class GrapheneQuery(graphene.ObjectType):
 
     permissions = graphene.Field(non_null_list(GraphenePermission))
 
-    class Meta:
-        name = "Query"
-
     def resolve_repositoriesOrError(self, graphene_info):
         return fetch_repositories(graphene_info)
 
@@ -270,6 +277,10 @@ class GrapheneQuery(graphene.ObjectType):
         else:
             return get_pipeline_snapshot_or_error_from_snapshot_id(graphene_info, snapshot_id_arg)
 
+    def resolve_graphOrError(self, graphene_info, **kwargs):
+        graph_selector = graph_selector_from_graphql(kwargs["selector"])
+        return get_graph_or_error(graphene_info, graph_selector)
+
     def resolve_version(self, graphene_info):
         return graphene_info.context.version
 
@@ -302,7 +313,9 @@ class GrapheneQuery(graphene.ObjectType):
         )
 
     def resolve_unloadableInstigationStatesOrError(self, graphene_info, **kwargs):
-        job_type = JobType(kwargs["instigationType"]) if "instigationType" in kwargs else None
+        job_type = (
+            InstigatorType(kwargs["instigationType"]) if "instigationType" in kwargs else None
+        )
         return get_unloadable_job_states_or_error(graphene_info, job_type)
 
     def resolve_pipelineOrError(self, graphene_info, **kwargs):
