@@ -1,6 +1,7 @@
 import graphene
 from dagster import check
 from dagster.core.host_representation import ExternalSchedule
+from dagster.core.scheduler.instigation import InstigatorState
 from dagster.seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
 
 from ..errors import (
@@ -37,20 +38,15 @@ class GrapheneSchedule(graphene.ObjectType):
     class Meta:
         name = "Schedule"
 
-    def __init__(self, graphene_info, external_schedule):
+    def __init__(self, external_schedule, schedule_state):
         self._external_schedule = check.inst_param(
             external_schedule, "external_schedule", ExternalSchedule
         )
-        self._schedule_state = graphene_info.context.instance.get_job_state(
-            self._external_schedule.get_external_origin_id()
+        self._schedule_state = check.opt_inst_param(
+            schedule_state, "schedule_state", InstigatorState
         )
-
         if not self._schedule_state:
-            # Also include a ScheduleState for a stopped schedule that may not
-            # have a stored database row yet
-            self._schedule_state = self._external_schedule.get_default_instigation_state(
-                graphene_info.context.instance
-            )
+            self._schedule_state = external_schedule.get_default_instigation_state()
 
         super().__init__(
             name=external_schedule.name,
