@@ -1,6 +1,8 @@
+from functools import lru_cache
+
 import graphene
 from dagster import check
-from dagster.core.definitions import SolidHandle
+from dagster.core.definitions import NodeHandle
 from dagster.core.host_representation import RepresentedPipeline
 from dagster.core.snap import CompositeSolidDefSnap, DependencyStructureIndex, SolidDefSnap
 
@@ -29,7 +31,7 @@ class GrapheneInputDefinition(graphene.ObjectType):
         )
         check.str_param(solid_def_name, "solid_def_name")
         check.str_param(input_def_name, "input_def_name")
-        solid_def_snap = self._represented_pipeline.get_solid_def_snap(solid_def_name)
+        solid_def_snap = self._represented_pipeline.get_node_def_snap(solid_def_name)
         self._input_def_snap = solid_def_snap.get_input_snap(input_def_name)
         super().__init__(
             name=self._input_def_snap.name,
@@ -64,7 +66,7 @@ class GrapheneOutputDefinition(graphene.ObjectType):
         check.str_param(solid_def_name, "solid_def_name")
         check.str_param(output_def_name, "output_def_name")
 
-        self._solid_def_snap = represented_pipeline.get_solid_def_snap(solid_def_name)
+        self._solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
         self._output_def_snap = self._solid_def_snap.get_output_snap(output_def_name)
 
         super().__init__(
@@ -102,7 +104,7 @@ class GrapheneInput(graphene.ObjectType):
         self._solid_name = check.str_param(solid_name, "solid_name")
         self._input_name = check.str_param(input_name, "input_name")
         self._solid_invocation_snap = current_dep_structure.get_invocation(solid_name)
-        self._solid_def_snap = represented_pipeline.get_solid_def_snap(
+        self._solid_def_snap = represented_pipeline.get_node_def_snap(
             self._solid_invocation_snap.solid_def_name
         )
         self._input_def_snap = self._solid_def_snap.get_input_snap(input_name)
@@ -156,7 +158,7 @@ class GrapheneOutput(graphene.ObjectType):
         self._solid_name = check.str_param(solid_name, "solid_name")
         self._output_name = check.str_param(output_name, "output_name")
         self._solid_invocation_snap = current_dep_structure.get_invocation(solid_name)
-        self._solid_def_snap = represented_pipeline.get_solid_def_snap(
+        self._solid_def_snap = represented_pipeline.get_node_def_snap(
             self._solid_invocation_snap.solid_def_name
         )
         self._output_def_snap = self._solid_def_snap.get_output_snap(output_name)
@@ -209,7 +211,7 @@ class GrapheneInputMapping(graphene.ObjectType):
         self._current_dep_index = check.inst_param(
             current_dep_index, "current_dep_index", DependencyStructureIndex
         )
-        self._solid_def_snap = represented_pipeline.get_solid_def_snap(solid_def_name)
+        self._solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
         self._input_mapping_snap = self._solid_def_snap.get_input_mapping_snap(input_name)
         super().__init__()
 
@@ -249,7 +251,7 @@ class GrapheneOutputMapping(graphene.ObjectType):
         self._current_dep_index = check.inst_param(
             current_dep_index, "current_dep_index", DependencyStructureIndex
         )
-        self._solid_def_snap = represented_pipeline.get_solid_def_snap(solid_def_name)
+        self._solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
         self._output_mapping_snap = self._solid_def_snap.get_output_mapping_snap(output_name)
         self._output_def_snap = self._solid_def_snap.get_output_snap(output_name)
 
@@ -294,7 +296,7 @@ def build_solids(represented_pipeline, current_dep_index):
     )
 
 
-def build_solid_handles(represented_pipeline, current_dep_index, parent=None):
+def _build_solid_handles(represented_pipeline, current_dep_index, parent=None):
     check.inst_param(represented_pipeline, "represented_pipeline", RepresentedPipeline)
     check.opt_inst_param(parent, "parent", GrapheneSolidHandle)
     all_handle = []
@@ -302,12 +304,12 @@ def build_solid_handles(represented_pipeline, current_dep_index, parent=None):
         solid_name, solid_def_name = solid_invocation.solid_name, solid_invocation.solid_def_name
         handle = GrapheneSolidHandle(
             solid=GrapheneSolid(represented_pipeline, solid_name, current_dep_index),
-            handle=SolidHandle(solid_name, parent.handleID if parent else None),
+            handle=NodeHandle(solid_name, parent.handleID if parent else None),
             parent=parent if parent else None,
         )
-        solid_def_snap = represented_pipeline.get_solid_def_snap(solid_def_name)
+        solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
         if isinstance(solid_def_snap, CompositeSolidDefSnap):
-            all_handle += build_solid_handles(
+            all_handle += _build_solid_handles(
                 represented_pipeline,
                 represented_pipeline.get_dep_structure_index(solid_def_name),
                 handle,
@@ -318,6 +320,17 @@ def build_solid_handles(represented_pipeline, current_dep_index, parent=None):
     return all_handle
 
 
+@lru_cache(maxsize=32)
+def build_solid_handles(represented_pipeline):
+    check.inst_param(represented_pipeline, "represented_pipeline", RepresentedPipeline)
+    return {
+        str(item.handleID): item
+        for item in _build_solid_handles(
+            represented_pipeline, represented_pipeline.dep_structure_index
+        )
+    }
+
+
 class GrapheneISolidDefinition(graphene.Interface):
     name = graphene.NonNull(graphene.String)
     description = graphene.String()
@@ -335,7 +348,7 @@ class ISolidDefinitionMixin:
             represented_pipeline, "represented_pipeline", RepresentedPipeline
         )
         check.str_param(solid_def_name, "solid_def_name")
-        self._solid_def_snap = represented_pipeline.get_solid_def_snap(solid_def_name)
+        self._solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
 
     def resolve_metadata(self, _graphene_info):
         return [
@@ -377,7 +390,7 @@ class GrapheneSolidDefinition(graphene.ObjectType, ISolidDefinitionMixin):
 
     def __init__(self, represented_pipeline, solid_def_name):
         check.inst_param(represented_pipeline, "represented_pipeline", RepresentedPipeline)
-        self._solid_def_snap = represented_pipeline.get_solid_def_snap(solid_def_name)
+        self._solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
         super().__init__(name=solid_def_name, description=self._solid_def_snap.description)
         ISolidDefinitionMixin.__init__(self, represented_pipeline, solid_def_name)
 
@@ -417,7 +430,7 @@ class GrapheneSolid(graphene.ObjectType):
             current_dep_structure, "current_dep_structure", DependencyStructureIndex
         )
         self._solid_invocation_snap = current_dep_structure.get_invocation(solid_name)
-        self._solid_def_snap = represented_pipeline.get_solid_def_snap(
+        self._solid_def_snap = represented_pipeline.get_node_def_snap(
             self._solid_invocation_snap.solid_def_name
         )
         super().__init__(name=solid_name)
@@ -457,17 +470,55 @@ class GrapheneSolid(graphene.ObjectType):
         return self._solid_invocation_snap.is_dynamic_mapped
 
 
+class GrapheneSolidHandle(graphene.ObjectType):
+    handleID = graphene.NonNull(graphene.String)
+    solid = graphene.NonNull(GrapheneSolid)
+    parent = graphene.Field(lambda: GrapheneSolidHandle)
+
+    class Meta:
+        name = "SolidHandle"
+
+    def __init__(self, handle, solid, parent=None):
+        super().__init__(
+            handleID=check.inst_param(handle, "handle", NodeHandle),
+            solid=check.inst_param(solid, "solid", GrapheneSolid),
+            parent=check.opt_inst_param(parent, "parent", GrapheneSolidHandle),
+        )
+
+
 class GrapheneSolidContainer(graphene.Interface):
+    id = graphene.NonNull(graphene.ID)
+    name = graphene.NonNull(graphene.String)
+    description = graphene.String()
     solids = non_null_list(GrapheneSolid)
+    solid_handle = graphene.Field(
+        GrapheneSolidHandle,
+        handleID=graphene.Argument(graphene.NonNull(graphene.String)),
+    )
+    solid_handles = graphene.Field(
+        non_null_list(GrapheneSolidHandle), parentHandleID=graphene.String()
+    )
+    modes = non_null_list("dagster_graphql.schema.pipelines.mode.GrapheneMode")
 
     class Meta:
         name = "SolidContainer"
 
 
 class GrapheneCompositeSolidDefinition(graphene.ObjectType, ISolidDefinitionMixin):
+    id = graphene.NonNull(graphene.ID)
+    name = graphene.NonNull(graphene.String)
+    description = graphene.String()
     solids = non_null_list(GrapheneSolid)
     input_mappings = non_null_list(GrapheneInputMapping)
     output_mappings = non_null_list(GrapheneOutputMapping)
+    solid_handle = graphene.Field(
+        GrapheneSolidHandle,
+        handleID=graphene.Argument(graphene.NonNull(graphene.String)),
+    )
+    solid_handles = graphene.Field(
+        non_null_list(GrapheneSolidHandle), parentHandleID=graphene.String()
+    )
+    modes = non_null_list("dagster_graphql.schema.pipelines.mode.GrapheneMode")
 
     class Meta:
         interfaces = (GrapheneISolidDefinition, GrapheneSolidContainer)
@@ -477,11 +528,14 @@ class GrapheneCompositeSolidDefinition(graphene.ObjectType, ISolidDefinitionMixi
         self._represented_pipeline = check.inst_param(
             represented_pipeline, "represented_pipeline", RepresentedPipeline
         )
-        self._solid_def_snap = represented_pipeline.get_solid_def_snap(solid_def_name)
+        self._solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
         self._comp_solid_dep_index = represented_pipeline.get_dep_structure_index(solid_def_name)
         super().__init__(name=solid_def_name, description=self._solid_def_snap.description)
         ISolidDefinitionMixin.__init__(self, represented_pipeline, solid_def_name)
 
+    def resolve_id(self, _graphene_info):
+        return f"{self._represented_pipeline.identifying_pipeline_snapshot_id}:{self._solid_def_snap.name}"
+
     def resolve_solids(self, _graphene_info):
         return build_solids(self._represented_pipeline, self._comp_solid_dep_index)
 
@@ -507,28 +561,35 @@ class GrapheneCompositeSolidDefinition(graphene.ObjectType, ISolidDefinitionMixi
             for input_def_snap in self._solid_def_snap.input_def_snaps
         ]
 
+    def resolve_solid_handle(self, _graphene_info, handleID):
+        return build_solid_handles(self._represented_pipeline).get(handleID)
 
-class GrapheneSolidHandle(graphene.ObjectType):
-    handleID = graphene.NonNull(graphene.String)
-    solid = graphene.NonNull(GrapheneSolid)
-    parent = graphene.Field(lambda: GrapheneSolidHandle)
+    def resolve_solid_handles(self, _graphene_info, **kwargs):
+        handles = build_solid_handles(self._represented_pipeline)
+        parentHandleID = kwargs.get("parentHandleID")
 
-    class Meta:
-        name = "SolidHandle"
+        if parentHandleID == "":
+            handles = {key: handle for key, handle in handles.items() if not handle.parent}
+        elif parentHandleID is not None:
+            handles = {
+                key: handle
+                for key, handle in handles.items()
+                if handle.parent and handle.parent.handleID.to_string() == parentHandleID
+            }
 
-    def __init__(self, handle, solid, parent):
-        super().__init__()
-        # FIXME this really seems wrong
-        self.handleID = check.inst_param(handle, "handle", SolidHandle)
-        self.solid = check.inst_param(solid, "solid", GrapheneSolid)
-        self.parent = check.opt_inst_param(parent, "parent", GrapheneSolidHandle)
+        return [handles[key] for key in sorted(handles)]
+
+    def resolve_modes(self, _graphene_info):
+        # returns empty list... composite solids don't have modes, this is a vestige of the old
+        # pipeline explorer, which expected all solid containers to be pipelines
+        return []
 
 
 def build_solid_definition(represented_pipeline, solid_def_name):
     check.inst_param(represented_pipeline, "represented_pipeline", RepresentedPipeline)
     check.str_param(solid_def_name, "solid_def_name")
 
-    solid_def_snap = represented_pipeline.get_solid_def_snap(solid_def_name)
+    solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
 
     if isinstance(solid_def_snap, SolidDefSnap):
         return GrapheneSolidDefinition(represented_pipeline, solid_def_snap.name)
