@@ -22,6 +22,9 @@ from dagster import (
     EventMetadataEntry,
     ExpectationResult,
     Field,
+    HourlyPartitionsDefinition,
+    IOManager,
+    IOManagerDefinition,
     InputDefinition,
     Int,
     Materialization,
@@ -37,6 +40,7 @@ from dagster import (
     ScheduleDefinition,
     ScheduleEvaluationContext,
     SolidExecutionContext,
+    StaticPartitionsDefinition,
     String,
     check,
     composite_solid,
@@ -45,9 +49,11 @@ from dagster import (
     daily_schedule,
     graph,
     hourly_schedule,
+    job,
     lambda_solid,
     logger,
     monthly_schedule,
+    op,
     pipeline,
     repository,
     resource,
@@ -55,9 +61,10 @@ from dagster import (
     usable_as_dagster_type,
     weekly_schedule,
 )
+from dagster.core.asset_defs import ForeignAsset, asset, build_assets_job
 from dagster.core.definitions.decorators.sensor import sensor
 from dagster.core.definitions.reconstructable import ReconstructableRepository
-from dagster.core.definitions.sensor import RunRequest, SkipReason
+from dagster.core.definitions.sensor_definition import RunRequest, SkipReason
 from dagster.core.log_manager import coerce_valid_log_level
 from dagster.core.storage.fs_io_manager import fs_io_manager
 from dagster.core.storage.pipeline_run import PipelineRunStatus, PipelineRunsFilter
@@ -1238,6 +1245,137 @@ def composed_graph():
     simple_graph()
 
 
+@job(config={"ops": {"a_solid_with_config": {"config": {"one": "hullo"}}}})
+def job_with_default_config():
+    @op(config_schema={"one": Field(String)})
+    def a_solid_with_config(context):
+        return context.op_config["one"]
+
+    a_solid_with_config()
+
+
+@resource(config_schema={"file": Field(String)})
+def hanging_asset_resource(context):
+    # Hack to allow asset to get value from run config
+    return context.resource_config.get("file")
+
+
+class DummyIOManager(IOManager):
+    def handle_output(self, context, obj):
+        pass
+
+    def load_input(self, context):
+        pass
+
+
+dummy_foreign_asset = ForeignAsset(key=AssetKey("dummy_foreign_asset"))
+
+
+@asset
+def first_asset(dummy_foreign_asset):  # pylint: disable=redefined-outer-name,unused-argument
+    return 1
+
+
+@asset(required_resource_keys={"hanging_asset_resource"})
+def hanging_asset(context, first_asset):  # pylint: disable=redefined-outer-name,unused-argument
+    """
+    Asset that hangs forever, used to test in-progress ops.
+    """
+    with open(context.resources.hanging_asset_resource, "w") as ff:
+        ff.write("yup")
+
+    while True:
+        time.sleep(0.1)
+
+
+@asset
+def never_runs_asset(hanging_asset):  # pylint: disable=redefined-outer-name,unused-argument
+    pass
+
+
+hanging_job = build_assets_job(
+    name="hanging_job",
+    source_assets=[dummy_foreign_asset],
+    assets=[first_asset, hanging_asset, never_runs_asset],
+    resource_defs={
+        "io_manager": IOManagerDefinition.hardcoded_io_manager(DummyIOManager()),
+        "hanging_asset_resource": hanging_asset_resource,
+    },
+)
+
+
+@asset
+def asset_one():
+    return 1
+
+
+@asset
+def asset_two(asset_one):  # pylint: disable=redefined-outer-name,unused-argument
+    return first_asset + 1
+
+
+two_assets_job = build_assets_job(name="two_assets_job", assets=[asset_one, asset_two])
+
+
+static_partitions_def = StaticPartitionsDefinition(["a", "b", "c", "d"])
+
+
+@asset(partitions_def=static_partitions_def)
+def upstream_static_partitioned_asset():
+    return 1
+
+
+@asset(partitions_def=static_partitions_def)
+def downstream_static_partitioned_asset(
+    upstream_static_partitioned_asset,
+):  # pylint: disable=redefined-outer-name
+    assert upstream_static_partitioned_asset
+
+
+static_partitioned_assets_job = build_assets_job(
+    "static_partitioned_assets_job",
+    assets=[upstream_static_partitioned_asset, downstream_static_partitioned_asset],
+)
+
+
+hourly_partition = HourlyPartitionsDefinition(start_date="2021-05-05-01:00")
+
+
+@asset(partitions_def=hourly_partition)
+def upstream_time_partitioned_asset():
+    return 1
+
+
+@asset(partitions_def=hourly_partition)
+def downstream_time_partitioned_asset(
+    upstream_time_partitioned_asset,
+):  # pylint: disable=redefined-outer-name
+    return upstream_time_partitioned_asset + 1
+
+
+time_partitioned_assets_job = build_assets_job(
+    "time_partitioned_assets_job",
+    [upstream_time_partitioned_asset, downstream_time_partitioned_asset],
+)
+
+
+@job
+def two_ins_job():
+    @op
+    def op_1():
+        return 1
+
+    @op
+    def op_2():
+        return 1
+
+    @op
+    def op_with_2_ins(in_1, in_2):
+        return in_1 + in_2
+
+    op_with_2_ins(op_1(), op_2())
+
+
 @repository
 def empty_repo():
     return []
@@ -1286,6 +1424,12 @@ def define_pipelines():
         simple_graph.to_job("simple_job_a"),
         simple_graph.to_job("simple_job_b"),
         composed_graph.to_job(),
+        job_with_default_config,
+        hanging_job,
+        two_ins_job,
+        two_assets_job,
+        static_partitioned_assets_job,
+        time_partitioned_assets_job,
     ]
 
 
