@@ -9,6 +9,22 @@ snapshots = Snapshot()
 snapshots['test_query_all_solids 1'] = {
     'repositoryOrError': {
         'usedSolids': [
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'a_solid_with_config'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'job_with_default_config'
+                        },
+                        'solidHandle': {
+                            'handleID': 'a_solid_with_config'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -201,6 +217,38 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'asset_one'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'two_assets_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'asset_one'
+                        }
+                    }
+                ]
+            },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'asset_two'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'two_assets_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'asset_two'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -233,6 +281,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'collect'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'eventually_successful'
+                        },
+                        'solidHandle': {
+                            'handleID': 'collect'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -305,6 +369,38 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'downstream_static_partitioned_asset'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'static_partitioned_assets_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'downstream_static_partitioned_asset'
+                        }
+                    }
+                ]
+            },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'downstream_time_partitioned_asset'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'time_partitioned_assets_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'downstream_time_partitioned_asset'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -433,6 +529,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'first_asset'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'hanging_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'first_asset'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -465,6 +577,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'hanging_asset'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'hanging_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'hanging_asset'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -585,6 +713,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'never_runs_asset'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'hanging_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'never_runs_asset'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -654,6 +798,30 @@ snapshots['test_query_all_solids 1'] = {
                         'solidHandle': {
                             'handleID': 'noop_solid'
                         }
+                    },
+                    {
+                        'pipeline': {
+                            'name': 'simple_job_a'
+                        },
+                        'solidHandle': {
+                            'handleID': 'noop_solid'
+                        }
+                    },
+                    {
+                        'pipeline': {
+                            'name': 'simple_job_b'
+                        },
+                        'solidHandle': {
+                            'handleID': 'noop_solid'
+                        }
+                    },
+                    {
+                        'pipeline': {
+                            'name': 'composed_graph'
+                        },
+                        'solidHandle': {
+                            'handleID': 'simple_graph.noop_solid'
+                        }
                     }
                 ]
             },
@@ -673,6 +841,54 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'op_1'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'two_ins_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'op_1'
+                        }
+                    }
+                ]
+            },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'op_2'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'two_ins_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'op_2'
+                        }
+                    }
+                ]
+            },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'op_with_2_ins'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'two_ins_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'op_with_2_ins'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -881,6 +1097,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'simple_graph'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'composed_graph'
+                        },
+                        'solidHandle': {
+                            'handleID': 'simple_graph'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -1201,6 +1433,38 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'upstream_static_partitioned_asset'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'static_partitioned_assets_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'upstream_static_partitioned_asset'
+                        }
+                    }
+                ]
+            },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'upstream_time_partitioned_asset'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'time_partitioned_assets_job'
+                        },
+                        'solidHandle': {
+                            'handleID': 'upstream_time_partitioned_asset'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
