@@ -27,7 +27,6 @@ def test_dynamic_resume_reexecution(graphql_context):
                 "selector": selector,
                 "runConfigData": {
                     "solids": {"multiply_inputs": {"inputs": {"should_fail": {"value": True}}}},
-                    "storage": {"filesystem": {}},
                 },
                 "mode": "default",
             }
@@ -36,7 +35,7 @@ def test_dynamic_resume_reexecution(graphql_context):
 
     assert not result.errors
     assert result.data
-    assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
+    assert result.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
     assert result.data["launchPipelineExecution"]["run"]["pipeline"]["name"] == "dynamic_pipeline"
 
     parent_run_id = result.data["launchPipelineExecution"]["run"]["runId"]
@@ -61,7 +60,7 @@ def test_dynamic_resume_reexecution(graphql_context):
                 "selector": selector,
                 "runConfigData": {
                     "solids": {"multiply_inputs": {"inputs": {"should_fail": {"value": True}}}},
-                    "storage": {"filesystem": {}},
+                    "execution": {"multiprocess": {}},
                 },
                 "executionMetadata": {
                     "rootRunId": parent_run_id,
@@ -74,7 +73,7 @@ def test_dynamic_resume_reexecution(graphql_context):
     assert not retry_one.errors
     assert retry_one.data
     assert (
-        retry_one.data["launchPipelineReexecution"]["__typename"] == "LaunchPipelineRunSuccess"
+        retry_one.data["launchPipelineReexecution"]["__typename"] == "LaunchRunSuccess"
     ), retry_one.data["launchPipelineReexecution"].get("message")
 
     run_id = retry_one.data["launchPipelineReexecution"]["run"]["runId"]
@@ -104,7 +103,6 @@ def test_dynamic_full_reexecution(graphql_context):
                 "selector": selector,
                 "runConfigData": {
                     "solids": {"multiply_inputs": {"inputs": {"should_fail": {"value": True}}}},
-                    "storage": {"filesystem": {}},
                 },
                 "mode": "default",
             }
@@ -113,7 +111,7 @@ def test_dynamic_full_reexecution(graphql_context):
 
     assert not result.errors
     assert result.data
-    assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
+    assert result.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
     assert result.data["launchPipelineExecution"]["run"]["pipeline"]["name"] == "dynamic_pipeline"
 
     parent_run_id = result.data["launchPipelineExecution"]["run"]["runId"]
@@ -138,7 +136,7 @@ def test_dynamic_full_reexecution(graphql_context):
                 "selector": selector,
                 "runConfigData": {
                     "solids": {"multiply_inputs": {"inputs": {"should_fail": {"value": True}}}},
-                    "storage": {"filesystem": {}},
+                    "execution": {"multiprocess": {}},
                 },
                 "executionMetadata": {
                     "rootRunId": parent_run_id,
@@ -151,7 +149,7 @@ def test_dynamic_full_reexecution(graphql_context):
     assert not retry_one.errors
     assert retry_one.data
     assert (
-        retry_one.data["launchPipelineReexecution"]["__typename"] == "LaunchPipelineRunSuccess"
+        retry_one.data["launchPipelineReexecution"]["__typename"] == "LaunchRunSuccess"
     ), retry_one.data["launchPipelineReexecution"].get("message")
 
     run_id = retry_one.data["launchPipelineReexecution"]["run"]["runId"]
@@ -181,7 +179,6 @@ def test_dynamic_subset(graphql_context):
                 "selector": selector,
                 "runConfigData": {
                     "solids": {"multiply_inputs": {"inputs": {"should_fail": {"value": True}}}},
-                    "storage": {"filesystem": {}},
                 },
                 "mode": "default",
             }
@@ -190,7 +187,7 @@ def test_dynamic_subset(graphql_context):
 
     assert not result.errors
     assert result.data
-    assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
+    assert result.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
     assert result.data["launchPipelineExecution"]["run"]["pipeline"]["name"] == "dynamic_pipeline"
 
     parent_run_id = result.data["launchPipelineExecution"]["run"]["runId"]
@@ -215,7 +212,7 @@ def test_dynamic_subset(graphql_context):
                 "selector": selector,
                 "runConfigData": {
                     "solids": {"multiply_inputs": {"inputs": {"should_fail": {"value": True}}}},
-                    "storage": {"filesystem": {}},
+                    "execution": {"multiprocess": {}},
                 },
                 "executionMetadata": {
                     "rootRunId": parent_run_id,
@@ -234,7 +231,7 @@ def test_dynamic_subset(graphql_context):
     assert not retry_one.errors
     assert retry_one.data
     assert (
-        retry_one.data["launchPipelineReexecution"]["__typename"] == "LaunchPipelineRunSuccess"
+        retry_one.data["launchPipelineReexecution"]["__typename"] == "LaunchRunSuccess"
     ), retry_one.data["launchPipelineReexecution"].get("message")
 
     run_id = retry_one.data["launchPipelineReexecution"]["run"]["runId"]
