@@ -6,7 +6,12 @@ from dagster.core.host_representation import (
     ExternalRepositoryOrigin,
     InProcessRepositoryLocationOrigin,
 )
-from dagster.core.scheduler.job import JobState, JobStatus, JobType, ScheduleJobData
+from dagster.core.scheduler.instigation import (
+    InstigatorState,
+    InstigatorStatus,
+    InstigatorType,
+    ScheduleInstigatorData,
+)
 from dagster.seven.compat.pendulum import create_pendulum_time
 from dagster_graphql.test.utils import (
     execute_dagster_graphql,
@@ -104,24 +109,6 @@ query getUnloadableSchedules {
 }
 """
 
-RECONCILE_SCHEDULER_STATE_QUERY = """
-mutation(
-  $repositorySelector: RepositorySelector!
-) {
-  reconcileSchedulerState(
-    repositorySelector: $repositorySelector,
-  ) {
-      ... on PythonError {
-        message
-        stack
-      }
-      ... on ReconcileSchedulerStateSuccess {
-        message
-      }
-    }
-}
-"""
-
 
 START_SCHEDULES_QUERY = """
 mutation(
@@ -209,11 +196,6 @@ def test_get_schedule_definitions_for_repository(graphql_context):
 
 
 def test_start_and_stop_schedule(graphql_context):
-    external_repository = graphql_context.get_repository_location(
-        main_repo_location_name()
-    ).get_repository(main_repo_name())
-    graphql_context.instance.reconcile_scheduler_state(external_repository)
-
     schedule_selector = infer_schedule_selector(
         graphql_context, "no_config_pipeline_hourly_schedule"
     )
@@ -224,7 +206,10 @@ def test_start_and_stop_schedule(graphql_context):
         START_SCHEDULES_QUERY,
         variables={"scheduleSelector": schedule_selector},
     )
-    assert start_result.data["startSchedule"]["scheduleState"]["status"] == JobStatus.RUNNING.value
+    assert (
+        start_result.data["startSchedule"]["scheduleState"]["status"]
+        == InstigatorStatus.RUNNING.value
+    )
 
     schedule_origin_id = start_result.data["startSchedule"]["scheduleState"]["id"]
 
@@ -236,13 +221,12 @@ def test_start_and_stop_schedule(graphql_context):
     )
     assert (
         stop_result.data["stopRunningSchedule"]["scheduleState"]["status"]
-        == JobStatus.STOPPED.value
+        == InstigatorStatus.STOPPED.value
     )
 
 
 def test_get_single_schedule_definition(graphql_context):
     context = graphql_context
-    instance = context.instance
 
     schedule_selector = infer_schedule_selector(context, "partition_based_multi_mode_decorator")
 
@@ -254,12 +238,6 @@ def test_get_single_schedule_definition(graphql_context):
     assert result.data["scheduleOrError"]["__typename"] == "Schedule"
     assert result.data["scheduleOrError"]["scheduleState"]
 
-    instance.reconcile_scheduler_state(
-        external_repository=context.get_repository_location(
-            main_repo_location_name()
-        ).get_repository(main_repo_name()),
-    )
-
     result = execute_dagster_graphql(
         context, GET_SCHEDULE_QUERY, variables={"scheduleSelector": schedule_selector}
     )
@@ -325,11 +303,6 @@ def test_get_single_schedule_definition(graphql_context):
 
 
 def test_next_tick(graphql_context):
-    external_repository = graphql_context.get_repository_location(
-        main_repo_location_name()
-    ).get_repository(main_repo_name())
-    graphql_context.instance.reconcile_scheduler_state(external_repository)
-
     schedule_selector = infer_schedule_selector(
         graphql_context, "no_config_pipeline_hourly_schedule"
     )
@@ -340,7 +313,10 @@ def test_next_tick(graphql_context):
         START_SCHEDULES_QUERY,
         variables={"scheduleSelector": schedule_selector},
     )
-    assert start_result.data["startSchedule"]["scheduleState"]["status"] == JobStatus.RUNNING.value
+    assert (
+        start_result.data["startSchedule"]["scheduleState"]["status"]
+        == InstigatorStatus.RUNNING.value
+    )
 
     # get schedule next tick
     result = execute_dagster_graphql(
@@ -358,11 +334,6 @@ def test_next_tick(graphql_context):
 
 
 def test_next_tick_bad_schedule(graphql_context):
-    external_repository = graphql_context.get_repository_location(
-        main_repo_location_name()
-    ).get_repository(main_repo_name())
-    graphql_context.instance.reconcile_scheduler_state(external_repository)
-
     schedule_selector = infer_schedule_selector(graphql_context, "run_config_error_schedule")
 
     # Start a single schedule, future tick run requests only available for running schedules
@@ -371,7 +342,10 @@ def test_next_tick_bad_schedule(graphql_context):
         START_SCHEDULES_QUERY,
         variables={"scheduleSelector": schedule_selector},
     )
-    assert start_result.data["startSchedule"]["scheduleState"]["status"] == JobStatus.RUNNING.value
+    assert (
+        start_result.data["startSchedule"]["scheduleState"]["status"]
+        == InstigatorStatus.RUNNING.value
+    )
 
     # get schedule next tick
     result = execute_dagster_graphql(
@@ -401,27 +375,25 @@ def test_get_unloadable_job(graphql_context):
     )
     with pendulum.test(initial_datetime):
         instance.add_job_state(
-            JobState(
+            InstigatorState(
                 _get_unloadable_schedule_origin("unloadable_running"),
-                JobType.SCHEDULE,
-                JobStatus.RUNNING,
-                ScheduleJobData(
+                InstigatorType.SCHEDULE,
+                InstigatorStatus.RUNNING,
+                ScheduleInstigatorData(
                     "0 0 * * *",
                     pendulum.now("UTC").timestamp(),
-                    graphql_context.instance.scheduler.__class__.__name__,
                 ),
             )
         )
 
         instance.add_job_state(
-            JobState(
+            InstigatorState(
                 _get_unloadable_schedule_origin("unloadable_stopped"),
-                JobType.SCHEDULE,
-                JobStatus.STOPPED,
-                ScheduleJobData(
+                InstigatorType.SCHEDULE,
+                InstigatorStatus.STOPPED,
+                ScheduleInstigatorData(
                     "0 0 * * *",
                     pendulum.now("UTC").timestamp(),
-                    graphql_context.instance.scheduler.__class__.__name__,
                 ),
             )
         )
